package net.wanji.feign.pojo.entity;

import lombok.Data;

import java.io.Serializable;

//没有get set方法会导致feign 接口调用时，无法使用JsonViewObject作为返回值
@Data
public class JsonViewObject implements Serializable {

    private Object content;
    private String message;
    private String status;
    private Integer code;
    private Long timestamp;

    public Object getContent() {
        return content;
    }

    public String getMessage() {
        return message;
    }

    public String getStatus() {
        return status;
    }

    private JsonViewObject() {
    }

    public static JsonViewObject newInstance() {
        return new JsonViewObject();
    }

    public JsonViewObject success() {
        return success((Object) "");
    }

    public JsonViewObject success(Object content) {
        return success(content, "");
    }

    public JsonViewObject success(String message) {
        return success("", message);
    }

    public JsonViewObject success(Object content, String message) {
        return pack(content, message, "success");
    }

    public JsonViewObject fail() {
        return fail("", "");
    }

    public JsonViewObject fail(Exception e) {
        String message = e.getMessage();
        int index = message.indexOf(":");
        return fail(index == -1 ? message : message.substring(index + 1));
    }

    public JsonViewObject fail(String errMsg) {
        return fail("", errMsg);
    }

    public JsonViewObject fail(Object content, String message) {
        return pack(content, message,"fail");
    }

    private JsonViewObject pack(Object content, String message, String status) {
        this.content = content;
        this.message = message;
        this.status = status;
        //增加服务返回状态码，后期待完善
        this.code=(status.equals("success") ? 200:500);
        return this;
    }
}